@@ -15,15 +15,5 @@ p <- df %>%
   geom_text(aes(label = scales::percent(prop)), position = position_stack(vjust = 0.5))  
 
 test_that("geom_col is supported", {
-  l <- save_outputs(p, "col")
-  barDat <- l$data[sapply(l$data, "[[", "type") %in% "bar"]
-  expect_equivalent(
-    unlist(lapply(barDat, "[[", "x")),
-    c(1, 2, 3, 1, 2, 3)
-  )
-  expect_equal(
-    unlist(lapply(barDat, "[[", "y")), 
-    c(0.7142857, 0.4827586, 0.2, 0.2857143, 0.5172414, 0.8),
-    tolerance = 0.0001
-  )
+  l <- expect_doppelganger_built(p, "col")
 })
